@@ -5,8 +5,8 @@ import bleak
 
 async def discover_bluetooth(device_str: str):
     print("Searching for bluetooth devices...")
-    devices = await bleak.discover()
-    wave_devices = [device for device in devices if device_str in device.name]
+    devices = await bleak.BleakScanner.discover()
+    wave_devices = [d for d in devices if (d.name is not None) and (device_str in d.name)]
     print("Found the following devices" if wave_devices else "Found no devices")
     for device in wave_devices:
         print(f"Address: {device.address} - Name: {device.name}")
